diff --git a/modules/util/util.py b/modules/util/util.py
index ac3baed1a140e13389a7dc228205ac98b52c48b6..46cddb4cf91210adc13085d85aa6f9b967674380 100644
--- a/modules/util/util.py
+++ b/modules/util/util.py
@@ -431,13 +431,15 @@ exmp_file_fd = '/Users/tomrink/data/OR_ABI-L1b-RadF-M6C16_G16_s20212521800223_e2
 # lon, lat = 120.955098, 23.834310
 # elem, line = (1789, 1505)
 # # UR from Taiwan
-# lon, lat = 131.117451, 32.850718
-# elem_ur, line_ur = (2317, 1087)
-taiwan_x0 = 1260
-taiwan_y0 = 1085
-taiwan_lenx = 1024
-taiwan_leny = 1024
-taiwain_extent = [-2420, -1420, 1992, 2992]  # GEOS coordinates, not line, elem
+# lon, lat = 135.0, 35.0
+# elem_ur, line_ur = (2499, 995)
+taiwan_x0 = 1079
+taiwan_y0 = 995
+taiwan_lenx = 1420
+taiwan_leny = 1020
+# geos.transform_point(135.0, 35.0, ccrs.PlateCarree(), False)
+# geos.transform_point(106.61, 13.97, ccrs.PlateCarree(), False)
+taiwain_extent = [-3342, -502, 1470, 3510]  # GEOS coordinates, not line, elem
 
 
 # ------------ This code will not be needed when we implement a Fully Connected CNN -----------------------------------